@@ -8,27 +8,10 @@
 
 defined( 'ABSPATH' ) || exit;
 
-use Automattic\WooCommerce\Internal\AssignDefaultCategory;
-use Automattic\WooCommerce\Internal\BatchProcessing\BatchProcessingController;
-use Automattic\WooCommerce\Internal\ComingSoon\ComingSoonAdminBarBadge;
-use Automattic\WooCommerce\Internal\ComingSoon\ComingSoonCacheInvalidator;
-use Automattic\WooCommerce\Internal\ComingSoon\ComingSoonRequestHandler;
-use Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController;
 use Automattic\WooCommerce\Internal\DownloadPermissionsAdjuster;
-use Automattic\WooCommerce\Internal\Features\FeaturesController;
+use Automattic\WooCommerce\Internal\AssignDefaultCategory;
 use Automattic\WooCommerce\Internal\ProductAttributesLookup\DataRegenerator;
-use Automattic\WooCommerce\Internal\ProductAttributesLookup\LookupDataStore;
-use Automattic\WooCommerce\Internal\ProductDownloads\ApprovedDirectories\Register as ProductDownloadDirectories;
-use Automattic\WooCommerce\Internal\ProductImage\MatchImageBySKU;
-use Automattic\WooCommerce\Internal\RegisterHooksInterface;
-use Automattic\WooCommerce\Internal\RestockRefundedItemsAdjuster;
-use Automattic\WooCommerce\Internal\Settings\OptionSanitizer;
-use Automattic\WooCommerce\Internal\Utilities\LegacyRestApiStub;
-use Automattic\WooCommerce\Internal\Utilities\WebhookUtil;
-use Automattic\WooCommerce\Internal\Admin\Marketplace;
 use Automattic\WooCommerce\Proxies\LegacyProxy;
-use Automattic\WooCommerce\Utilities\{LoggingUtil, RestApiUtil, TimeUtil};
-use Automattic\WooCommerce\Internal\Logging\RemoteLogger;
 
 /**
  * Main WooCommerce Class.
@@ -42,7 +25,7 @@ final class WooCommerce {
 	 *
 	 * @var string
 	 */
-	public $version = '9.7.0';
+	public $version = '5.4.1';
 
 	/**
 	 * WooCommerce Schema version.
@@ -51,7 +34,7 @@ final class WooCommerce {
 	 *
 	 * @var string
 	 */
-	public $db_version = '920';
+	public $db_version = '430';
 
 	/**
 	 * The single instance of the class.
@@ -75,15 +58,6 @@ final class WooCommerce {
 	 */
 	public $query = null;
 
-	/**
-	 * API instance
-	 *
-	 * @deprecated 9.0.0 The Legacy REST API has been removed from WooCommerce core. Now this property points to a RestApiUtil instance, unless the Legacy REST API plugin is installed.
-	 *
-	 * @var WC_API
-	 */
-	private $api;
-
 	/**
 	 * Product factory instance.
 	 *
@@ -176,57 +150,17 @@ final class WooCommerce {
 	}
 
 	/**
-	 * Autoload inaccessible or non-existing properties on demand.
+	 * Auto-load in-accessible properties on demand.
 	 *
 	 * @param mixed $key Key name.
 	 * @return mixed
 	 */
 	public function __get( $key ) {
-		if ( 'api' === $key ) {
-			// The Legacy REST API was removed from WooCommerce core as of version 9.0 (moved to a dedicated plugin),
-			// but some plugins are still using wc()->api->get_endpoint_data. This method now lives in the RestApiUtil class,
-			// but we expose it through LegacyRestApiStub to limit the scope of what can be done via WC()->api.
-			//
-			// On the other hand, if the dedicated plugin is installed it will set the $api property by itself
-			// to an instance of the old WC_API class, which of course still has the get_endpoint_data method.
-			if ( is_null( $this->api ) && ! $this->legacy_rest_api_is_available() ) {
-				$this->api = wc_get_container()->get( LegacyRestApiStub::class );
-			}
-
-			return $this->api;
-		}
-
 		if ( in_array( $key, array( 'payment_gateways', 'shipping', 'mailer', 'checkout' ), true ) ) {
 			return $this->$key();
 		}
 	}
 
-	/**
-	 * Set the value of an inaccessible or non-existing property.
-	 *
-	 * @param string $key Property name.
-	 * @param mixed  $value Property value.
-	 * @throws Exception Attempt to access a property that's private or protected.
-	 */
-	public function __set( string $key, $value ) {
-		if ( 'api' === $key ) {
-			$this->api = $value;
-		} elseif ( property_exists( $this, $key ) ) {
-			throw new Exception( 'Cannot access private property ' . __CLASS__ . '::$' . esc_html( $key ) );
-		} else {
-			$this->$key = $value;
-		}
-	}
-
-	/**
-	 * Check if the Legacy REST API plugin is active (and thus the Legacy REST API is available).
-	 *
-	 * @return bool
-	 */
-	public function legacy_rest_api_is_available() {
-		return class_exists( 'WC_Legacy_REST_API_Plugin', false );
-	}
-
 	/**
 	 * WooCommerce Constructor.
 	 */
@@ -247,32 +181,9 @@ final class WooCommerce {
 	 * @since 3.6.0
 	 */
 	public function on_plugins_loaded() {
-		/**
-		 * Action to signal that WooCommerce has finished loading.
-		 *
-		 * @since 3.6.0
-		 */
 		do_action( 'woocommerce_loaded' );
 	}
 
-	/**
-	 * Initialize Jetpack Connection Config.
-	 *
-	 * @return void
-	 */
-	public function init_jetpack_connection_config() {
-		$config = new Automattic\Jetpack\Config();
-		$config->ensure(
-			'connection',
-			array(
-				'slug' => 'woocommerce',
-				// Cannot use __() here because it would cause translations to be loaded too early.
-				// See https://github.com/woocommerce/woocommerce/pull/47113.
-				'name' => 'WooCommerce',
-			)
-		);
-	}
-
 	/**
 	 * Hook into actions and filters.
 	 *
@@ -283,81 +194,30 @@ final class WooCommerce {
 		register_shutdown_function( array( $this, 'log_errors' ) );
 
 		add_action( 'plugins_loaded', array( $this, 'on_plugins_loaded' ), -1 );
-		add_action( 'plugins_loaded', array( $this, 'init_jetpack_connection_config' ), 1 );
 		add_action( 'admin_notices', array( $this, 'build_dependencies_notice' ) );
 		add_action( 'after_setup_theme', array( $this, 'setup_environment' ) );
 		add_action( 'after_setup_theme', array( $this, 'include_template_functions' ), 11 );
-		add_action( 'load-post.php', array( $this, 'includes' ) );
 		add_action( 'init', array( $this, 'init' ), 0 );
 		add_action( 'init', array( 'WC_Shortcodes', 'init' ) );
 		add_action( 'init', array( 'WC_Emails', 'init_transactional_emails' ) );
 		add_action( 'init', array( $this, 'add_image_sizes' ) );
 		add_action( 'init', array( $this, 'load_rest_api' ) );
-		if ( $this->is_request( 'admin' ) || ( $this->is_rest_api_request() && ! $this->is_store_api_request() ) || ( defined( 'WP_CLI' ) && WP_CLI ) ) {
-			add_action( 'init', array( 'WC_Site_Tracking', 'init' ) );
-		}
 		add_action( 'switch_blog', array( $this, 'wpdb_table_fix' ), 0 );
 		add_action( 'activated_plugin', array( $this, 'activated_plugin' ) );
 		add_action( 'deactivated_plugin', array( $this, 'deactivated_plugin' ) );
 		add_action( 'woocommerce_installed', array( $this, 'add_woocommerce_inbox_variant' ) );
 		add_action( 'woocommerce_updated', array( $this, 'add_woocommerce_inbox_variant' ) );
-		add_action( 'rest_api_init', array( $this, 'register_wp_admin_settings' ) );
-		add_action( 'woocommerce_installed', array( $this, 'add_woocommerce_remote_variant' ) );
-		add_action( 'woocommerce_updated', array( $this, 'add_woocommerce_remote_variant' ) );
-		add_action( 'woocommerce_newly_installed', 'wc_set_hooked_blocks_version', 10 );
-		add_action( 'update_option_woocommerce_allow_tracking', array( $this, 'get_tracking_history' ), 10, 2 );
-
-		add_filter( 'robots_txt', array( $this, 'robots_txt' ) );
-		add_filter( 'wp_plugin_dependencies_slug', array( $this, 'convert_woocommerce_slug' ) );
-		add_filter( 'woocommerce_register_log_handlers', array( $this, 'register_remote_log_handler' ) );
 
 		// These classes set up hooks on instantiation.
-		$container = wc_get_container();
-		$container->get( ProductDownloadDirectories::class );
-		$container->get( DownloadPermissionsAdjuster::class );
-		$container->get( AssignDefaultCategory::class );
-		$container->get( DataRegenerator::class );
-		$container->get( LookupDataStore::class );
-		$container->get( MatchImageBySKU::class );
-		$container->get( RestockRefundedItemsAdjuster::class );
-		$container->get( CustomOrdersTableController::class );
-		$container->get( OptionSanitizer::class );
-		$container->get( BatchProcessingController::class );
-		$container->get( FeaturesController::class );
-		$container->get( WebhookUtil::class );
-		$container->get( Marketplace::class );
-		$container->get( TimeUtil::class );
-		$container->get( ComingSoonAdminBarBadge::class );
-		$container->get( ComingSoonCacheInvalidator::class );
-		$container->get( ComingSoonRequestHandler::class );
-
-		/**
-		 * These classes have a register method for attaching hooks.
-		 */
-		$container->get( Automattic\WooCommerce\Internal\Utilities\PluginInstaller::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\TransientFiles\TransientFilesEngine::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Orders\OrderAttributionController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Orders\OrderAttributionBlocksController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\CostOfGoodsSold\CostOfGoodsSoldController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Admin\Settings\PaymentsController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Utilities\LegacyRestApiStub::class )->register();
-		Automattic\WooCommerce\Internal\Admin\WcPayWelcomePage::instance()->register();
-
-		// Classes inheriting from RestApiControllerBase.
-		$container->get( Automattic\WooCommerce\Internal\ReceiptRendering\ReceiptRenderingRestController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Orders\OrderActionsRestController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Orders\OrderStatusRestController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Admin\Settings\PaymentsRestController::class )->register();
-		$container->get( Automattic\WooCommerce\Internal\Admin\EmailPreview\EmailPreviewRestController::class )->register();
+		wc_get_container()->get( DownloadPermissionsAdjuster::class );
+		wc_get_container()->get( AssignDefaultCategory::class );
+		wc_get_container()->get( DataRegenerator::class );
 	}
 
 	/**
 	 * Add woocommerce_inbox_variant for the Remote Inbox Notification.
 	 *
 	 * P2 post can be found at https://wp.me/paJDYF-1uJ.
-	 *
-	 * This will no longer be used. The more flexible add_woocommerce_remote_variant
-	 * below will be used instead.
 	 */
 	public function add_woocommerce_inbox_variant() {
 		$config_name = 'woocommerce_inbox_variant_assignment';
@@ -365,18 +225,6 @@ final class WooCommerce {
 			update_option( $config_name, wp_rand( 1, 12 ) );
 		}
 	}
-
-	/**
-	 * Add woocommerce_remote_variant_assignment used to determine cohort
-	 * or group assignment for Remote Spec Engines.
-	 */
-	public function add_woocommerce_remote_variant() {
-		$config_name = 'woocommerce_remote_variant_assignment';
-		if ( false === get_option( $config_name, false ) ) {
-			update_option( $config_name, wp_rand( 1, 120 ) );
-		}
-	}
-
 	/**
 	 * Ensures fatal errors are logged so they can be picked up in the status report.
 	 *
@@ -385,41 +233,14 @@ final class WooCommerce {
 	public function log_errors() {
 		$error = error_get_last();
 		if ( $error && in_array( $error['type'], array( E_ERROR, E_PARSE, E_COMPILE_ERROR, E_USER_ERROR, E_RECOVERABLE_ERROR ), true ) ) {
-			$error_copy = $error;
-			$message    = $error_copy['message'];
-			unset( $error_copy['message'] );
-
-			$context = array(
-				'source'         => 'fatal-errors',
-				'error'          => $error_copy,
-				// Indicate that this error should be logged remotely if remote logging is enabled.
-				'remote-logging' => true,
-			);
-
-			if ( false !== strpos( $message, 'Stack trace:' ) ) {
-				$segments  = explode( 'Stack trace:', $message );
-				$message   = str_replace( PHP_EOL, ' ', trim( $segments[0] ) );
-				$backtrace = array_map(
-					'trim',
-					explode( PHP_EOL, $segments[1] )
-				);
-
-				$context['backtrace'] = $backtrace;
-			} else {
-				$context['backtrace'] = true;
-			}
-
 			$logger = wc_get_logger();
 			$logger->critical(
-				$message,
-				$context
+				/* translators: 1: error message 2: file name and path 3: line number */
+				sprintf( __( '%1$s in %2$s on line %3$s', 'woocommerce' ), $error['message'], $error['file'], $error['line'] ) . PHP_EOL,
+				array(
+					'source' => 'fatal-errors',
+				)
 			);
-
-			/**
-			 * Action triggered when there are errors during shutdown.
-			 *
-			 * @since 3.2.0
-			 */
 			do_action( 'woocommerce_shutdown_error', $error );
 		}
 	}
@@ -428,6 +249,8 @@ final class WooCommerce {
 	 * Define WC Constants.
 	 */
 	private function define_constants() {
+		$upload_dir = wp_upload_dir( null, false );
+
 		$this->define( 'WC_ABSPATH', dirname( WC_PLUGIN_FILE ) . '/' );
 		$this->define( 'WC_PLUGIN_BASENAME', plugin_basename( WC_PLUGIN_FILE ) );
 		$this->define( 'WC_VERSION', $this->version );
@@ -436,25 +259,12 @@ final class WooCommerce {
 		$this->define( 'WC_DISCOUNT_ROUNDING_MODE', 2 );
 		$this->define( 'WC_TAX_ROUNDING_MODE', 'yes' === get_option( 'woocommerce_prices_include_tax', 'no' ) ? 2 : 1 );
 		$this->define( 'WC_DELIMITER', '|' );
+		$this->define( 'WC_LOG_DIR', $upload_dir['basedir'] . '/wc-logs/' );
 		$this->define( 'WC_SESSION_CACHE_GROUP', 'wc_session_id' );
 		$this->define( 'WC_TEMPLATE_DEBUG_MODE', false );
-
-		/**
-		 * As of 8.8.0, it is preferable to use the `woocommerce_log_directory` filter hook to change the log
-		 * directory. WC_LOG_DIR_CUSTOM is a back-compatibility measure so we can tell if `WC_LOG_DIR` has been
-		 * defined outside of WC Core.
-		 */
-		if ( defined( 'WC_LOG_DIR' ) ) {
-			$this->define( 'WC_LOG_DIR_CUSTOM', true );
-		} else {
-			$this->define( 'WC_LOG_DIR', LoggingUtil::get_log_directory( false ) );
-		}
-
-		// These three are kept defined for compatibility, but are no longer used.
 		$this->define( 'WC_NOTICE_MIN_PHP_VERSION', '7.2' );
 		$this->define( 'WC_NOTICE_MIN_WP_VERSION', '5.2' );
 		$this->define( 'WC_PHP_MIN_REQUIREMENTS_NOTICE', 'wp_php_min_requirements_' . WC_NOTICE_MIN_PHP_VERSION . '_' . WC_NOTICE_MIN_WP_VERSION );
-
 		/** Define if we're checking against major, minor or no versions in the following places:
 		 *   - plugin screen in WP Admin (displaying extra warning when updating to new major versions)
 		 *   - System Status Report ('Installed version not tested with active version of WooCommerce' warning)
@@ -466,6 +276,7 @@ final class WooCommerce {
 		 * The SSR in the name is preserved for bw compatibility, as this was initially used in System Status Report.
 		 */
 		$this->define( 'WC_SSR_PLUGIN_UPDATE_RELEASE_VERSION_TYPE', 'none' );
+
 	}
 
 	/**
@@ -518,27 +329,9 @@ final class WooCommerce {
 		$rest_prefix         = trailingslashit( rest_get_url_prefix() );
 		$is_rest_api_request = ( false !== strpos( $_SERVER['REQUEST_URI'], $rest_prefix ) ); // phpcs:disable WordPress.Security.ValidatedSanitizedInput.MissingUnslash, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
 
-		/**
-		 * Whether this is a REST API request.
-		 *
-		 * @since 3.6.0
-		 */
 		return apply_filters( 'woocommerce_is_rest_api_request', $is_rest_api_request );
 	}
 
-	/**
-	 * Returns true if the request is a store REST API request.
-	 *
-	 * @return bool
-	 */
-	public function is_store_api_request() {
-		if ( empty( $_SERVER['REQUEST_URI'] ) ) {
-			return false;
-		}
-		// phpcs:disable WordPress.Security.ValidatedSanitizedInput.MissingUnslash, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
-		return false !== strpos( $_SERVER['REQUEST_URI'], trailingslashit( rest_get_url_prefix() ) . 'wc/store/' );
-	}
-
 	/**
 	 * Load REST API.
 	 */
@@ -661,7 +454,6 @@ final class WooCommerce {
 		include_once WC_ABSPATH . 'includes/queue/class-wc-action-queue.php';
 		include_once WC_ABSPATH . 'includes/queue/class-wc-queue.php';
 		include_once WC_ABSPATH . 'includes/admin/marketplace-suggestions/class-wc-marketplace-updater.php';
-		include_once WC_ABSPATH . 'includes/admin/class-wc-admin-marketplace-promotions.php';
 		include_once WC_ABSPATH . 'includes/blocks/class-wc-blocks-utils.php';
 
 		/**
@@ -695,30 +487,18 @@ final class WooCommerce {
 		/**
 		 * REST API.
 		 */
+		include_once WC_ABSPATH . 'includes/legacy/class-wc-legacy-api.php';
+		include_once WC_ABSPATH . 'includes/class-wc-api.php';
 		include_once WC_ABSPATH . 'includes/class-wc-rest-authentication.php';
 		include_once WC_ABSPATH . 'includes/class-wc-rest-exception.php';
 		include_once WC_ABSPATH . 'includes/class-wc-auth.php';
 		include_once WC_ABSPATH . 'includes/class-wc-register-wp-admin-settings.php';
 
-		/**
-		 * Tracks.
-		 */
-		include_once WC_ABSPATH . 'includes/tracks/class-wc-tracks.php';
-		include_once WC_ABSPATH . 'includes/tracks/class-wc-tracks-event.php';
-		include_once WC_ABSPATH . 'includes/tracks/class-wc-tracks-client.php';
-		include_once WC_ABSPATH . 'includes/tracks/class-wc-tracks-footer-pixel.php';
-		include_once WC_ABSPATH . 'includes/tracks/class-wc-site-tracking.php';
-
 		/**
 		 * WCCOM Site.
 		 */
 		include_once WC_ABSPATH . 'includes/wccom-site/class-wc-wccom-site.php';
 
-		/**
-		 * Product Usage
-		 */
-		include_once WC_ABSPATH . 'includes/product-usage/class-wc-product-usage.php';
-
 		/**
 		 * Libraries and packages.
 		 */
@@ -730,25 +510,20 @@ final class WooCommerce {
 
 		if ( $this->is_request( 'admin' ) ) {
 			include_once WC_ABSPATH . 'includes/admin/class-wc-admin.php';
-			// Simulate loading plugin for the legacy reports.
-			// This will be removed after moving the legacy reports to a separate plugin.
-			include_once WC_ABSPATH . 'includes/admin/woocommerce-legacy-reports.php';
 		}
 
-		// We load frontend includes in the post editor, because they may be invoked via pre-loading of blocks.
-		$in_post_editor = doing_action( 'load-post.php' ) || doing_action( 'load-post-new.php' );
-
-		if ( $this->is_request( 'frontend' ) || $this->is_rest_api_request() || $in_post_editor ) {
+		if ( $this->is_request( 'frontend' ) ) {
 			$this->frontend_includes();
 		}
 
 		if ( $this->is_request( 'cron' ) && 'yes' === get_option( 'woocommerce_allow_tracking', 'no' ) ) {
 			include_once WC_ABSPATH . 'includes/class-wc-tracker.php';
-			WC_Tracker::init();
 		}
 
 		$this->theme_support_includes();
 		$this->query = new WC_Query();
+		$this->api   = new WC_API();
+		$this->api->init();
 	}
 
 	/**
@@ -792,12 +567,6 @@ final class WooCommerce {
 				case 'twentytwentyone':
 					include_once WC_ABSPATH . 'includes/theme-support/class-wc-twenty-twenty-one.php';
 					break;
-				case 'twentytwentytwo':
-					include_once WC_ABSPATH . 'includes/theme-support/class-wc-twenty-twenty-two.php';
-					break;
-				case 'twentytwentythree':
-					include_once WC_ABSPATH . 'includes/theme-support/class-wc-twenty-twenty-three.php';
-					break;
 			}
 		}
 	}
@@ -831,10 +600,8 @@ final class WooCommerce {
 	 * Init WooCommerce when WordPress Initialises.
 	 */
 	public function init() {
-		/**
-		 * Action triggered before WooCommerce initialization begins.
-		 */
-		do_action( 'before_woocommerce_init' ); // phpcs:ignore WooCommerce.Commenting.CommentHooks.MissingSinceComment
+		// Before init action.
+		do_action( 'before_woocommerce_init' );
 
 		// Set up localisation.
 		$this->load_plugin_textdomain();
@@ -855,10 +622,8 @@ final class WooCommerce {
 
 		$this->load_webhooks();
 
-		/**
-		 * Action triggered after WooCommerce initialization finishes.
-		 */
-		do_action( 'woocommerce_init' ); // phpcs:ignore WooCommerce.Commenting.CommentHooks.MissingSinceComment
+		// Init action.
+		do_action( 'woocommerce_init' );
 	}
 
 	/**
@@ -872,13 +637,9 @@ final class WooCommerce {
 	 */
 	public function load_plugin_textdomain() {
 		$locale = determine_locale();
+		$locale = apply_filters( 'plugin_locale', $locale, 'woocommerce' );
 
-		/**
-		 * Filter to adjust the WooCommerce locale to use for translations.
-		 */
-		$locale = apply_filters( 'plugin_locale', $locale, 'woocommerce' ); // phpcs:ignore WooCommerce.Commenting.CommentHooks.MissingSinceComment
-
-		unload_textdomain( 'woocommerce', true );
+		unload_textdomain( 'woocommerce' );
 		load_textdomain( 'woocommerce', WP_LANG_DIR . '/woocommerce/woocommerce-' . $locale . '.mo' );
 		load_plugin_textdomain( 'woocommerce', false, plugin_basename( dirname( WC_PLUGIN_FILE ) ) . '/i18n/languages' );
 	}
@@ -929,6 +690,15 @@ final class WooCommerce {
 		add_image_size( 'woocommerce_thumbnail', $thumbnail['width'], $thumbnail['height'], $thumbnail['crop'] );
 		add_image_size( 'woocommerce_single', $single['width'], $single['height'], $single['crop'] );
 		add_image_size( 'woocommerce_gallery_thumbnail', $gallery_thumbnail['width'], $gallery_thumbnail['height'], $gallery_thumbnail['crop'] );
+
+		/**
+		 * Legacy image sizes.
+		 *
+		 * @deprecated 3.3.0 These sizes will be removed in 4.6.0.
+		 */
+		add_image_size( 'shop_catalog', $thumbnail['width'], $thumbnail['height'], $thumbnail['crop'] );
+		add_image_size( 'shop_single', $single['width'], $single['height'], $single['crop'] );
+		add_image_size( 'shop_thumbnail', $gallery_thumbnail['width'], $gallery_thumbnail['height'], $gallery_thumbnail['crop'] );
 	}
 
 	/**
@@ -955,10 +725,7 @@ final class WooCommerce {
 	 * @return string
 	 */
 	public function template_path() {
-		/**
-		 * Filter to adjust the base templates path.
-		 */
-		return apply_filters( 'woocommerce_template_path', 'woocommerce/' ); // phpcs:ignore WooCommerce.Commenting.CommentHooks.MissingSinceComment
+		return apply_filters( 'woocommerce_template_path', 'woocommerce/' );
 	}
 
 	/**
@@ -994,10 +761,7 @@ final class WooCommerce {
 			$api_request_url = add_query_arg( 'wc-api', $request, trailingslashit( home_url( '', $scheme ) ) );
 		}
 
-		/**
-		 * Filter to adjust the url of an incoming API request.
-		 */
-		return esc_url_raw( apply_filters( 'woocommerce_api_request_url', $api_request_url, $request, $ssl ) );  // phpcs:ignore WooCommerce.Commenting.CommentHooks.MissingSinceComment
+		return esc_url_raw( apply_filters( 'woocommerce_api_request_url', $api_request_url, $request, $ssl ) );
 	}
 
 	/**
@@ -1025,15 +789,14 @@ final class WooCommerce {
 	/**
 	 * Initialize the customer and cart objects and setup customer saving on shutdown.
 	 *
-	 * Note, wc()->customer is session based. Changes to customer data via this property are not persisted to the database automatically.
-	 *
 	 * @since 3.6.4
 	 * @return void
 	 */
 	public function initialize_cart() {
+		// Cart needs customer info.
 		if ( is_null( $this->customer ) || ! $this->customer instanceof WC_Customer ) {
 			$this->customer = new WC_Customer( get_current_user_id(), true );
-			// Customer session should be saved during shutdown.
+			// Customer should be saved during shutdown.
 			add_action( 'shutdown', array( $this->customer, 'save' ), 10 );
 		}
 		if ( is_null( $this->cart ) || ! $this->cart instanceof WC_Cart ) {
@@ -1048,55 +811,14 @@ final class WooCommerce {
 	 * @return void
 	 */
 	public function initialize_session() {
-		/**
-		 * Filter to overwrite the session class that handles session data for users.
-		 */
-		$session_class = apply_filters( 'woocommerce_session_handler', 'WC_Session_Handler' ); // phpcs:ignore WooCommerce.Commenting.CommentHooks.MissingSinceComment
+		// Session class, handles session data for users - can be overwritten if custom handler is needed.
+		$session_class = apply_filters( 'woocommerce_session_handler', 'WC_Session_Handler' );
 		if ( is_null( $this->session ) || ! $this->session instanceof $session_class ) {
 			$this->session = new $session_class();
 			$this->session->init();
 		}
 	}
 
-	/**
-	 * Tell bots not to index some WooCommerce-created directories.
-	 *
-	 * We try to detect the default "User-agent: *" added by WordPress and add our rules to that group, because
-	 * it's possible that some bots will only interpret the first group of rules if there are multiple groups with
-	 * the same user agent.
-	 *
-	 * @param string $output The contents that WordPress will output in a robots.txt file.
-	 *
-	 * @return string
-	 *
-	 * @internal For exclusive usage of WooCommerce core, backwards compatibility not guaranteed.
-	 */
-	public function robots_txt( $output ) {
-		$path = ( ! empty( $site_url['path'] ) ) ? $site_url['path'] : '';
-
-		$lines       = preg_split( '/\r\n|\r|\n/', $output );
-		$agent_index = array_search( 'User-agent: *', $lines, true );
-
-		if ( false !== $agent_index ) {
-			$above = array_slice( $lines, 0, $agent_index + 1 );
-			$below = array_slice( $lines, $agent_index + 1 );
-		} else {
-			$above = $lines;
-			$below = array();
-
-			$above[] = '';
-			$above[] = 'User-agent: *';
-		}
-
-		$above[] = "Disallow: $path/wp-content/uploads/wc-logs/";
-		$above[] = "Disallow: $path/wp-content/uploads/woocommerce_transient_files/";
-		$above[] = "Disallow: $path/wp-content/uploads/woocommerce_uploads/";
-
-		$lines = array_merge( $above, $below );
-
-		return implode( PHP_EOL, $lines );
-	}
-
 	/**
 	 * Set tablenames inside WPDB object.
 	 */
@@ -1111,7 +833,7 @@ final class WooCommerce {
 	 * @param string $filename The filename of the activated plugin.
 	 */
 	public function activated_plugin( $filename ) {
-		include_once __DIR__ . '/admin/helper/class-wc-helper.php';
+		include_once dirname( __FILE__ ) . '/admin/helper/class-wc-helper.php';
 
 		if ( '/woocommerce.php' === substr( $filename, -16 ) ) {
 			set_transient( 'woocommerce_activated_plugin', $filename );
@@ -1127,7 +849,7 @@ final class WooCommerce {
 	 * @param string $filename The filename of the deactivated plugin.
 	 */
 	public function deactivated_plugin( $filename ) {
-		include_once __DIR__ . '/admin/helper/class-wc-helper.php';
+		include_once dirname( __FILE__ ) . '/admin/helper/class-wc-helper.php';
 
 		WC_Helper::deactivated_plugin( $filename );
 	}
@@ -1206,7 +928,7 @@ final class WooCommerce {
 			return;
 		}
 
-		$message_one = __( 'You have installed a development version of WooCommerce which requires files to be built and minified. From the plugin directory, run <code>pnpm install</code> and then <code>pnpm --filter=\'@woocommerce/plugin-woocommerce\' build</code> to build and minify assets.', 'woocommerce' );
+		$message_one = __( 'You have installed a development version of WooCommerce which requires files to be built and minified. From the plugin directory, run <code>grunt assets</code> to build and minify assets.', 'woocommerce' );
 		$message_two = sprintf(
 			/* translators: 1: URL of WordPress.org Repository 2: URL of the GitHub Repository release page */
 			__( 'Or you can download a pre-built version of the plugin from the <a href="%1$s">WordPress.org repository</a> or by visiting <a href="%2$s">the releases page in the GitHub repository</a>.', 'woocommerce' ),
@@ -1281,86 +1003,4 @@ final class WooCommerce {
 	public function get_instance_of( string $class_name, ...$args ) {
 		return wc_get_container()->get( LegacyProxy::class )->get_instance_of( $class_name, ...$args );
 	}
-
-	/**
-	 * Gets the value of a global.
-	 *
-	 * @param string $global_name The name of the global to get the value for.
-	 * @return mixed The value of the global.
-	 */
-	public function get_global( string $global_name ) {
-		return wc_get_container()->get( LegacyProxy::class )->get_global( $global_name );
-	}
-
-	/**
-	 * Register WC settings from WP-API to the REST API.
-	 *
-	 * This method used to be part of the now removed Legacy REST API.
-	 *
-	 * @since 9.0.0
-	 *
-	 * @internal For exclusive usage of WooCommerce core, backwards compatibility not guaranteed.
-	 */
-	public function register_wp_admin_settings() {
-		$pages = WC_Admin_Settings::get_settings_pages();
-		foreach ( $pages as $page ) {
-			new WC_Register_WP_Admin_Settings( $page, 'page' );
-		}
-
-		$emails = WC_Emails::instance();
-		foreach ( $emails->get_emails() as $email ) {
-			new WC_Register_WP_Admin_Settings( $email, 'email' );
-		}
-	}
-
-	/**
-	 * Converts the WooCommerce slug to the correct slug for the current version.
-	 * This ensures that when the plugin is installed in a different folder name, the correct slug is used so that dependent plugins can be installed/activated.
-	 *
-	 * @since 9.0.0
-	 * @param string $slug The plugin slug to convert.
-	 *
-	 * @return string
-	 */
-	public function convert_woocommerce_slug( $slug ) {
-		if ( 'woocommerce' === $slug ) {
-			$slug = dirname( WC_PLUGIN_BASENAME );
-		}
-		return $slug;
-	}
-
-	/**
-	 * Register the remote log handler.
-	 *
-	 * @param \WC_Log_Handler[] $handlers The handlers to register.
-	 *
-	 * @return \WC_Log_Handler[]
-	 *
-	 * @internal For exclusive usage of WooCommerce core, backwards compatibility not guaranteed.
-	 */
-	public function register_remote_log_handler( $handlers ) {
-		$handlers[] = wc_get_container()->get( RemoteLogger::class );
-		return $handlers;
-	}
-
-	/**
-	 * Tracks the history WooCommerce Allow Tracking option.
-	 * - When the field was first set to allow tracking
-	 * - Last time the option was changed
-	 *
-	 * @param string $old_value The old value for the woocommerce_allow_tracking option.
-	 * @param string $value The current value for the woocommerce_allow_tracking option.
-	 * @since x.x.x
-	 *
-	 * @return void
-	 */
-	public function get_tracking_history( $old_value, $value ) {
-		// If woocommerce_allow_tracking_first_optin is not set. It means is the first time it gets set.
-		if ( ! get_option( 'woocommerce_allow_tracking_first_optin' ) && 'yes' === $value ) {
-			update_option( 'woocommerce_allow_tracking_first_optin', time() );
-		}
-
-		// Always update the last change.
-		update_option( 'woocommerce_allow_tracking_last_modified', time() );
-	}
 }
