@@ -15,7 +15,7 @@ if ( ! function_exists( 'add_filter' ) ) {
  * {@internal Nobody should be able to overrule the real version number as this can cause
  *            serious issues with the options, so no if ( ! defined() ).}}
  */
-define( 'WPSEO_VERSION', '13.2' );
+define( 'WPSEO_VERSION', '8.1.1' );
 
 
 if ( ! defined( 'WPSEO_PATH' ) ) {
@@ -26,23 +26,10 @@ if ( ! defined( 'WPSEO_BASENAME' ) ) {
 	define( 'WPSEO_BASENAME', plugin_basename( WPSEO_FILE ) );
 }
 
-/*
- * {@internal The prefix constants are used to build prefixed versions of dependencies.
- *            These should not be changed on run-time, thus missing the ! defined() check.}}
- */
-define( 'YOAST_VENDOR_NS_PREFIX', 'YoastSEO_Vendor' );
-define( 'YOAST_VENDOR_DEFINE_PREFIX', 'YOASTSEO_VENDOR__' );
-define( 'YOAST_VENDOR_PREFIX_DIRECTORY', 'vendor_prefixed' );
-
-if ( ! defined( 'WPSEO_NAMESPACES' ) ) {
-	define( 'WPSEO_NAMESPACES', true );
-}
-
-
 /* ***************************** CLASS AUTOLOADING *************************** */
 
 /**
- * Autoload our class files.
+ * Auto load our class files
  *
  * @param string $class Class name.
  *
@@ -52,10 +39,11 @@ function wpseo_auto_load( $class ) {
 	static $classes = null;
 
 	if ( $classes === null ) {
-		$classes = [
+		$classes = array(
 			'wp_list_table'   => ABSPATH . 'wp-admin/includes/class-wp-list-table.php',
 			'walker_category' => ABSPATH . 'wp-includes/category-template.php',
-		];
+			'pclzip'          => ABSPATH . 'wp-admin/includes/class-pclzip.php',
+		);
 	}
 
 	$cn = strtolower( $class );
@@ -65,10 +53,8 @@ function wpseo_auto_load( $class ) {
 	}
 }
 
-$yoast_autoload_file = WPSEO_PATH . 'vendor/autoload.php';
-
-if ( is_readable( $yoast_autoload_file ) ) {
-	require $yoast_autoload_file;
+if ( file_exists( WPSEO_PATH . 'vendor/autoload_52.php' ) ) {
+	require WPSEO_PATH . 'vendor/autoload_52.php';
 }
 elseif ( ! class_exists( 'WPSEO_Options' ) ) { // Still checking since might be site-level autoload R.
 	add_action( 'admin_init', 'yoast_wpseo_missing_autoload', 1 );
@@ -83,17 +69,17 @@ if ( function_exists( 'spl_autoload_register' ) ) {
 /* ********************* DEFINES DEPENDING ON AUTOLOADED CODE ********************* */
 
 /**
- * Defaults to production, for safety.
+ * Defaults to production, for safety
  */
 if ( ! defined( 'YOAST_ENVIRONMENT' ) ) {
 	define( 'YOAST_ENVIRONMENT', 'production' );
 }
 
 /**
- * Only use minified assets when we are in a production environment.
+ * Only use minified assets when we are in a production environment
  */
 if ( ! defined( 'WPSEO_CSSJS_SUFFIX' ) ) {
-	define( 'WPSEO_CSSJS_SUFFIX', ( YOAST_ENVIRONMENT !== 'development' ) ? '.min' : '' );
+	define( 'WPSEO_CSSJS_SUFFIX', ( 'development' !== YOAST_ENVIRONMENT ) ? '.min' : '' );
 }
 
 /* ***************************** PLUGIN (DE-)ACTIVATION *************************** */
@@ -108,7 +94,7 @@ function wpseo_activate( $networkwide = false ) {
 		_wpseo_activate();
 	}
 	else {
-		/* Multi-site network activation - activate the plugin for all blogs. */
+		/* Multi-site network activation - activate the plugin for all blogs */
 		wpseo_network_activate_deactivate( true );
 	}
 }
@@ -123,13 +109,13 @@ function wpseo_deactivate( $networkwide = false ) {
 		_wpseo_deactivate();
 	}
 	else {
-		/* Multi-site network activation - de-activate the plugin for all blogs. */
+		/* Multi-site network activation - de-activate the plugin for all blogs */
 		wpseo_network_activate_deactivate( false );
 	}
 }
 
 /**
- * Run network-wide (de-)activation of the plugin.
+ * Run network-wide (de-)activation of the plugin
  *
  * @param bool $activate True for plugin activation, false for de-activation.
  */
@@ -138,7 +124,7 @@ function wpseo_network_activate_deactivate( $activate = true ) {
 
 	$network_blogs = $wpdb->get_col( $wpdb->prepare( "SELECT blog_id FROM $wpdb->blogs WHERE site_id = %d", $wpdb->siteid ) );
 
-	if ( is_array( $network_blogs ) && $network_blogs !== [] ) {
+	if ( is_array( $network_blogs ) && $network_blogs !== array() ) {
 		foreach ( $network_blogs as $blog_id ) {
 			switch_to_blog( $blog_id );
 
@@ -200,8 +186,8 @@ function _wpseo_activate() {
 	$notifier->manage_notification();
 
 	// Schedule cronjob when it doesn't exists on activation.
-	$wpseo_ryte = new WPSEO_Ryte();
-	$wpseo_ryte->activate_hooks();
+	$wpseo_onpage = new WPSEO_OnPage();
+	$wpseo_onpage->activate_hooks();
 
 	do_action( 'wpseo_activate' );
 }
@@ -241,17 +227,13 @@ function _wpseo_deactivate() {
  * {@internal Unfortunately will fail if the plugin is in the must-use directory.
  *            {@link https://core.trac.wordpress.org/ticket/24205} }}
  *
- * @param int|WP_Site $blog_id Blog ID.
+ * @param int $blog_id Blog ID.
  */
 function wpseo_on_activate_blog( $blog_id ) {
 	if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
 		require_once ABSPATH . 'wp-admin/includes/plugin.php';
 	}
 
-	if ( $blog_id instanceof WP_Site ) {
-		$blog_id = (int) $blog_id->blog_id;
-	}
-
 	if ( is_plugin_active_for_network( plugin_basename( WPSEO_FILE ) ) ) {
 		switch_to_blog( $blog_id );
 		wpseo_activate( false );
@@ -259,16 +241,17 @@ function wpseo_on_activate_blog( $blog_id ) {
 	}
 }
 
+
 /* ***************************** PLUGIN LOADING *************************** */
 
 /**
- * Load translations.
+ * Load translations
  */
 function wpseo_load_textdomain() {
 	$wpseo_path = str_replace( '\\', '/', WPSEO_PATH );
 	$mu_path    = str_replace( '\\', '/', WPMU_PLUGIN_DIR );
 
-	if ( stripos( $wpseo_path, $mu_path ) !== false ) {
+	if ( false !== stripos( $wpseo_path, $mu_path ) ) {
 		load_muplugin_textdomain( 'wordpress-seo', dirname( WPSEO_BASENAME ) . '/languages/' );
 	}
 	else {
@@ -280,7 +263,7 @@ add_action( 'plugins_loaded', 'wpseo_load_textdomain' );
 
 
 /**
- * On plugins_loaded: load the minimum amount of essential files for this plugin.
+ * On plugins_loaded: load the minimum amount of essential files for this plugin
  */
 function wpseo_init() {
 	require_once WPSEO_PATH . 'inc/wpseo-functions.php';
@@ -307,7 +290,7 @@ function wpseo_init() {
 		$GLOBALS['wpseo_sitemaps'] = new WPSEO_Sitemaps();
 	}
 
-	if ( ! wp_doing_ajax() ) {
+	if ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) {
 		require_once WPSEO_PATH . 'inc/wpseo-non-ajax-functions.php';
 	}
 
@@ -321,26 +304,23 @@ function wpseo_init() {
 	$link_watcher = new WPSEO_Link_Watcher_Loader();
 	$link_watcher->load();
 
-	$integrations   = [];
+	$integrations   = array();
 	$integrations[] = new WPSEO_Slug_Change_Watcher();
-	$integrations[] = new WPSEO_Structured_Data_Blocks();
+
+	if ( defined( 'YOAST_FEATURE_GUTENBERG_STRUCTURED_DATA_BLOCKS' ) ) {
+		$integrations[] = new WPSEO_Structured_Data_Blocks();
+	}
 
 	foreach ( $integrations as $integration ) {
 		$integration->register_hooks();
 	}
 
 	// Loading Ryte integration.
-	$wpseo_ryte = new WPSEO_Ryte();
-	$wpseo_ryte->register_hooks();
+	$wpseo_onpage = new WPSEO_OnPage();
+	$wpseo_onpage->register_hooks();
 
-	// Feature flag introduced to resolve problems with composer installation in 11.8.
-	if ( defined( 'YOAST_SEO_EXPERIMENTAL_PHP56' ) && YOAST_SEO_EXPERIMENTAL_PHP56 ) {
-		// When namespaces are not available, stop further execution.
-		if ( version_compare( PHP_VERSION, '5.6.0', '>=' ) ) {
-			require_once WPSEO_PATH . 'src/main.php';
-			// require_once WPSEO_PATH . 'src/loaders/oauth.php'; Temporarily disabled.
-		}
-	}
+	$wpseo_content_images = new WPSEO_Content_Images();
+	$wpseo_content_images->register_hooks();
 }
 
 /**
@@ -356,18 +336,20 @@ function wpseo_init_rest_api() {
 	$configuration_service = new WPSEO_Configuration_Service();
 	$configuration_service->initialize();
 
-	$statistics_service    = new WPSEO_Statistics_Service( new WPSEO_Statistics() );
+	$link_reindex_endpoint = new WPSEO_Link_Reindex_Post_Endpoint( new WPSEO_Link_Reindex_Post_Service() );
+	$link_reindex_endpoint->register();
 
-	$endpoints   = [];
-	$endpoints[] = new WPSEO_Link_Reindex_Post_Endpoint( new WPSEO_Link_Reindex_Post_Service() );
-	$endpoints[] = new WPSEO_Endpoint_Indexable( new WPSEO_Indexable_Service() );
-	$endpoints[] = new WPSEO_Endpoint_File_Size( new WPSEO_File_Size_Service() );
-	$endpoints[] = new WPSEO_Endpoint_Statistics( $statistics_service );
-	$endpoints[] = new WPSEO_Endpoint_MyYoast_Connect();
+	$ryte_endpoint_service = new WPSEO_Ryte_Service( new WPSEO_OnPage_Option() );
+	$ryte_endpoint         = new WPSEO_Endpoint_Ryte( $ryte_endpoint_service );
+	$ryte_endpoint->register();
 
-	foreach ( $endpoints as $endpoint ) {
-		$endpoint->register();
-	}
+	$indexable_service  = new WPSEO_Indexable_Service();
+	$indexable_endpoint = new WPSEO_Endpoint_Indexable( $indexable_service );
+	$indexable_endpoint->register();
+
+	$statistics_service  = new WPSEO_Statistics_Service( new WPSEO_Statistics() );
+	$statistics_endpoint = new WPSEO_Endpoint_Statistics( $statistics_service );
+	$statistics_endpoint->register();
 }
 
 /**
@@ -391,11 +373,11 @@ function wpseo_frontend_init() {
 }
 
 /**
- * Instantiate the different social classes on the frontend.
+ * Instantiate the different social classes on the frontend
  */
 function wpseo_frontend_head_init() {
 	if ( WPSEO_Options::get( 'twitter' ) === true ) {
-		add_action( 'wpseo_head', [ 'WPSEO_Twitter', 'get_instance' ], 40 );
+		add_action( 'wpseo_head', array( 'WPSEO_Twitter', 'get_instance' ), 40 );
 	}
 
 	if ( WPSEO_Options::get( 'opengraph' ) === true ) {
@@ -419,41 +401,29 @@ function wpseo_admin_init() {
  */
 function wpseo_cli_init() {
 	if ( WPSEO_Utils::is_yoast_seo_premium() ) {
-		WP_CLI::add_command(
-			'yoast redirect list',
-			'WPSEO_CLI_Redirect_List_Command',
-			[ 'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce' ]
-		);
+		WP_CLI::add_command( 'yoast redirect list', 'WPSEO_CLI_Redirect_List_Command', array(
+			'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce',
+		) );
 
-		WP_CLI::add_command(
-			'yoast redirect create',
-			'WPSEO_CLI_Redirect_Create_Command',
-			[ 'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce' ]
-		);
+		WP_CLI::add_command( 'yoast redirect create', 'WPSEO_CLI_Redirect_Create_Command', array(
+			'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce',
+		) );
 
-		WP_CLI::add_command(
-			'yoast redirect update',
-			'WPSEO_CLI_Redirect_Update_Command',
-			[ 'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce' ]
-		);
+		WP_CLI::add_command( 'yoast redirect update', 'WPSEO_CLI_Redirect_Update_Command', array(
+			'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce',
+		) );
 
-		WP_CLI::add_command(
-			'yoast redirect delete',
-			'WPSEO_CLI_Redirect_Delete_Command',
-			[ 'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce' ]
-		);
+		WP_CLI::add_command( 'yoast redirect delete', 'WPSEO_CLI_Redirect_Delete_Command', array(
+			'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce',
+		) );
 
-		WP_CLI::add_command(
-			'yoast redirect has',
-			'WPSEO_CLI_Redirect_Has_Command',
-			[ 'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce' ]
-		);
+		WP_CLI::add_command( 'yoast redirect has', 'WPSEO_CLI_Redirect_Has_Command', array(
+			'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce',
+		) );
 
-		WP_CLI::add_command(
-			'yoast redirect follow',
-			'WPSEO_CLI_Redirect_Follow_Command',
-			[ 'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce' ]
-		);
+		WP_CLI::add_command( 'yoast redirect follow', 'WPSEO_CLI_Redirect_Follow_Command', array(
+			'before_invoke' => 'WPSEO_CLI_Premium_Requirement::enforce',
+		) );
 	}
 
 	// Only add the namespace if the required base class exists (WP-CLI 1.5.0+).
@@ -490,10 +460,7 @@ if ( ! wp_installing() && ( $spl_autoload_exists && $filter_exists ) ) {
 
 		new Yoast_Alerts();
 
-		$yoast_addon_manager = new WPSEO_Addon_Manager();
-		$yoast_addon_manager->register_hooks();
-
-		if ( wp_doing_ajax() ) {
+		if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
 			require_once WPSEO_PATH . 'admin/ajax.php';
 
 			// Plugin conflict ajax hooks.
@@ -516,25 +483,12 @@ if ( ! wp_installing() && ( $spl_autoload_exists && $filter_exists ) ) {
 	if ( defined( 'WP_CLI' ) && WP_CLI ) {
 		add_action( 'plugins_loaded', 'wpseo_cli_init', 20 );
 	}
-
-	add_filter( 'phpcompat_whitelist', 'yoast_free_phpcompat_whitelist' );
-
-	add_action( 'init', [ 'WPSEO_Replace_Vars', 'setup_statics_once' ] );
 }
 
 // Activation and deactivation hook.
 register_activation_hook( WPSEO_FILE, 'wpseo_activate' );
 register_deactivation_hook( WPSEO_FILE, 'wpseo_deactivate' );
-
-// Wpmu_new_blog has been deprecated in 5.1 and replaced by wp_insert_site.
-global $wp_version;
-if ( version_compare( $wp_version, '5.1', '<' ) ) {
-	add_action( 'wpmu_new_blog', 'wpseo_on_activate_blog' );
-}
-else {
-	add_action( 'wp_initialize_site', 'wpseo_on_activate_blog', 99 );
-}
-
+add_action( 'wpmu_new_blog', 'wpseo_on_activate_blog' );
 add_action( 'activate_blog', 'wpseo_on_activate_blog' );
 
 // Registers SEO capabilities.
@@ -555,7 +509,7 @@ function load_yoast_notifications() {
 
 
 /**
- * Throw an error if the PHP SPL extension is disabled (prevent white screens) and self-deactivate plugin.
+ * Throw an error if the PHP SPL extension is disabled (prevent white screens) and self-deactivate plugin
  *
  * @since 1.5.4
  *
@@ -570,7 +524,7 @@ function yoast_wpseo_missing_spl() {
 }
 
 /**
- * Returns the notice in case of missing spl extension.
+ * Returns the notice in case of missing spl extension
  */
 function yoast_wpseo_missing_spl_notice() {
 	$message = esc_html__( 'The Standard PHP Library (SPL) extension seem to be unavailable. Please ask your web host to enable it.', 'wordpress-seo' );
@@ -578,7 +532,7 @@ function yoast_wpseo_missing_spl_notice() {
 }
 
 /**
- * Throw an error if the Composer autoload is missing and self-deactivate plugin.
+ * Throw an error if the Composer autoload is missing and self-deactivate plugin
  *
  * @return void
  */
@@ -591,7 +545,7 @@ function yoast_wpseo_missing_autoload() {
 }
 
 /**
- * Returns the notice in case of missing Composer autoload.
+ * Returns the notice in case of missing Composer autoload
  */
 function yoast_wpseo_missing_autoload_notice() {
 	/* translators: %1$s expands to Yoast SEO, %2$s / %3$s: links to the installation manual in the Readme for the Yoast SEO code repository on GitHub */
@@ -601,7 +555,7 @@ function yoast_wpseo_missing_autoload_notice() {
 }
 
 /**
- * Throw an error if the filter extension is disabled (prevent white screens) and self-deactivate plugin.
+ * Throw an error if the filter extension is disabled (prevent white screens) and self-deactivate plugin
  *
  * @since 2.0
  *
@@ -616,7 +570,7 @@ function yoast_wpseo_missing_filter() {
 }
 
 /**
- * Returns the notice in case of missing filter extension.
+ * Returns the notice in case of missing filter extension
  */
 function yoast_wpseo_missing_filter_notice() {
 	$message = esc_html__( 'The filter extension seem to be unavailable. Please ask your web host to enable it.', 'wordpress-seo' );
@@ -629,11 +583,11 @@ function yoast_wpseo_missing_filter_notice() {
  * @param string $message Message string.
  */
 function yoast_wpseo_activation_failed_notice( $message ) {
-	echo '<div class="error"><p>' . esc_html__( 'Activation failed:', 'wordpress-seo' ) . ' ' . strip_tags( $message, '<a>' ) . '</p></div>';
+	echo '<div class="error"><p>' . esc_html__( 'Activation failed:', 'wordpress-seo' ) . ' ' . $message . '</p></div>';
 }
 
 /**
- * The method will deactivate the plugin, but only once, done by the static $is_deactivated.
+ * The method will deactivate the plugin, but only once, done by the static $is_deactivated
  */
 function yoast_wpseo_self_deactivate() {
 	static $is_deactivated;
@@ -646,29 +600,3 @@ function yoast_wpseo_self_deactivate() {
 		}
 	}
 }
-
-/**
- * Excludes specific files from php-compatibility-checker.
- *
- * @since 9.4
- *
- * @param array $ignored Array of ignored directories/files.
- *
- * @return array Array of ignored directories/files.
- */
-function yoast_free_phpcompat_whitelist( $ignored ) {
-	$path = '*/' . basename( WPSEO_PATH ) . '/';
-
-	// To prevent: (warning) File has mixed line endings; this may cause incorrect results.
-	$ignored[] = $path . 'vendor/ruckusing/lib/Ruckusing/FrameworkRunner.php';
-	$ignored[] = $path . 'vendor_prefixed/ruckusing/lib/Ruckusing/FrameworkRunner.php';
-
-	/*
-	 * To prevent: (error) Extension 'sqlite' is removed since PHP 5.4.
-	 * Ignoring because we are not using the sqlite functionality.
-	 */
-	$ignored[] = $path . 'vendor/ruckusing/lib/Ruckusing/Adapter/Sqlite3/Base.php';
-	$ignored[] = $path . 'vendor_prefixed/ruckusing/lib/Ruckusing/Adapter/Sqlite3/Base.php';
-
-	return $ignored;
-}
